## What changed?

Brief description of changes.

## Why?

Motivation, problem being solved, or issue being fixed.

## Testing plan

How should this be tested? List verification steps:

- [ ] Step 1
- [ ] Step 2

## Breaking changes?

- [ ] Yes
- [ ] No

## Pre-merge checklist

- [ ] CI is passing
- [ ] Tests added/updated
- [ ] Documentation updated
- [ ] No debug statements or commented code
- [ ] No `print()` statements (use logging)

## Related issues

Closes #123
